/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.shape;

import java.awt.Color;
import java.util.List;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import nl.cloudfarming.client.util.swing.FormRow;
import org.openide.util.NbBundle;

/**
 * Form row for a single shape property/attribute mapping.
 * 
 * @author johan
 */
@NbBundle.Messages({
    "Shape property mapping formrow name label=Name: ",
    "Shape property mapping formrow name tooltip=Name",
    "Shape property mapping formrow value label=Value: ",
    "Shape property mapping formrow value tooltip=Value",
    "Shape property mapping formrow no properties message=None found"
})
public class ShapePropertyMappingFormRow extends FormRow {
    private final DefaultComboBoxModel<String> propertiesModel;
    private final JComboBox<String> propertiesComboBox;

    private ShapePropertyMappingFormRow(boolean required, JLabel label, JComboBox<String> component) {
        super(required, label, component);
        this.propertiesComboBox = component;
        this.propertiesComboBox.setBackground(Color.WHITE);
        this.propertiesModel = (DefaultComboBoxModel<String>) component.getModel();
    }

    public JComboBox getPropertiesComboBox() {
        return propertiesComboBox;
    }

    public String getSelectedProperty(){
        return (String) propertiesModel.getSelectedItem();
    }
    
    public void setSelectedProperty(String property){
        propertiesModel.setSelectedItem(property);
    }
    
    public void setAvailableProperties(List<String> properties) {
        propertiesModel.removeAllElements();
        propertiesComboBox.removeAllItems();
        
        if (properties == null || properties.isEmpty()) {
            propertiesModel.addElement(Bundle.Shape_property_mapping_formrow_no_properties_message());
            propertiesComboBox.setEnabled(false);
        } else {
            propertiesComboBox.setEnabled(true);
            for (String property : properties) {
                propertiesModel.addElement(property);
            }
            if (propertiesModel.getIndexOf("") >= 0) {
                propertiesModel.setSelectedItem("");
            }
        }
    }
    
    public static ShapePropertyMappingFormRow create(boolean required, String labelText, String labelTooltipText) {
        JLabel label = new JLabel(labelText);
        label.setToolTipText(labelTooltipText);
        return new ShapePropertyMappingFormRow(required, label, new JComboBox<>(new DefaultComboBoxModel<String>()));
    }
    
    public static ShapePropertyMappingFormRow createNameRow(boolean required) {
        return create(required, Bundle.Shape_property_mapping_formrow_name_label(), Bundle.Shape_property_mapping_formrow_name_tooltip());
    }

    public static ShapePropertyMappingFormRow createValueRow(boolean required) {
        return create(required, Bundle.Shape_property_mapping_formrow_value_label(), Bundle.Shape_property_mapping_formrow_value_tooltip());
    }
}
