/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.shape.preview;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.field.shape.ShapePropertyMappingFormRow;

/**
 * Allows the user to select the properties from a shape file which represent
 * the 'Name' and 'Value' of a shape.
 *
 * @author Gerben Feenstra
 * @author johan
 */
public class ShapePropertyMappingPanel extends JPanel {
    
    public static final String PROP_COMBOBOX_MAPPING_NAME = "nameMappingBox";
    public static final String PROP_COMBOBOX_MAPPING_VALUE = "valueMappingBox";
    
    private final ShapePropertyMappingFormRow nameRow = ShapePropertyMappingFormRow.createNameRow(false);
    private final ShapePropertyMappingFormRow valueRow = ShapePropertyMappingFormRow.createValueRow(false);

    public ShapePropertyMappingPanel() {
        this.setLayout(new MigLayout("wrap 1, insets 0 8 0 0"));
        this.setBackground(Color.white);

        this.add(nameRow);
        this.add(valueRow);
        
        nameRow.getPropertiesComboBox().addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                firePropertyChange(PROP_COMBOBOX_MAPPING_NAME, null, nameRow.getSelectedProperty());
            }
        });
        
        valueRow.getPropertiesComboBox().addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                firePropertyChange(PROP_COMBOBOX_MAPPING_VALUE, null, valueRow.getSelectedProperty());
            }
        });
    }

    public  void setAvailableNameProperties(List<String> properties) {
        nameRow.setAvailableProperties(properties);
    }
    
    public  void setAvailableValueProperties(List<String> properties) {
        valueRow.setAvailableProperties(properties);
    }

    public void setSelectedNameProperty(String property){
        nameRow.setSelectedProperty(property);
    }
    
    public void setSelectedValueProperty(String property){
        valueRow.setSelectedProperty(property);
    }
}
